@@ -57,18 +57,18 @@ async def exec_access(inc: InputContext,
             assert inc.dto
             retrieved = await AccessDMW.create(model, inc.identity, inc.dto, **inc.r_kwargs)
             if isinstance(retrieved, list):
-                return json([await i.values_dict() for i in retrieved])
-            return json(await retrieved.values_dict())
+                return [await i.values_dict() for i in retrieved]
+            return await retrieved.values_dict()
 
         case "PATCH":
             assert inc.dto
             entity_id = inc.r_kwargs.pop("entity_id")
             assert entity_id
             retrieved = await AccessDMW.update(model, entity_id, inc.identity, inc.dto, **inc.r_kwargs)
-            return json(await retrieved.values_dict())
+            return await retrieved.values_dict()
 
         case "DELETE":
             entity_id = inc.r_kwargs.pop("entity_id")
             assert entity_id
             retrieved = await AccessDMW.delete(model, entity_id, inc.identity, **inc.r_kwargs)
-            return json(await retrieved.values_dict())
+            return await retrieved.values_dict()
\ No newline at end of file
